@@ -182,15 +182,15 @@ async def run_task(task_data: dict):
         await client.initialize()
 
         result = await client.call_tool(task.setup_tool) # type: ignore
-        print(f"✅ Setup: {{result.content}}")
+        print(f"✅ Setup: {result.content}")
         
         print("\\n🔄 Performing actions:")
         for _ in range(10):
-            result = await client.call_tool(name="act", arguments={{}})
-            print(f"  {{result.content}}")
+            result = await client.call_tool(name="act", arguments={})
+            print(f"  {result.content}")
         
         result = await client.call_tool(task.evaluate_tool) # type: ignore
-        print(f"\\n📊 Evaluation: {{result.content}}")
+        print(f"\\n📊 Evaluation: {result.content}")
         
         return result.content
     except Exception as e:
